@@ -3,7 +3,7 @@ import unittest
 
 import numpy as np
 
-from tbase.common.cmd_util import set_global_seeds
+from tbase.common.cmd_util import get_infer_start_day, set_global_seeds
 
 
 class TestCmdUtil(unittest.TestCase):
@@ -15,6 +15,9 @@ class TestCmdUtil(unittest.TestCase):
         self.assertEqual(0.8444218515250481, random.random())
         self.assertEqual(0.5488135039273248, np.random.random())
 
+    def test_get_infer_start_day(self):
+        self.assertEqual('20200101', get_infer_start_day('20200111', 10))
+
 
 if __name__ == '__main__':
     unittest.main()
